@@ -504,6 +504,7 @@ typedef void (*funcvoid)(void);
 /* unixfsys.c:209:OF */ extern void coerce_to_filename (object pathname, char *p); /* (pathname, p) object pathname; char *p; */
 /* unixfsys.c:329:OF */ extern bool file_exists (object file); /* (file) object file; */
 /* unixfsys.c:359:OF */ extern FILE *backup_fopen (char *filename, char *option); /* (filename, option) char *filename; char *option; */
+/* unixfsys.c:359:OF */ extern FILE *fopen_not_dir (char *filename, char *option); /* (filename, option) char *filename; char *option; */
 /* unixfsys.c:372:OF */ extern int file_len (FILE *fp); /* (fp) FILE *fp; */
 /* unixfsys.c:382:OF */ extern object truename (object); /* () */
 /* unixfsys.c:382:OF */ extern void Ltruename (void); /* () */
@@ -547,6 +548,7 @@ typedef void (*funcvoid)(void);
 
 
 /*  readline.d */
+extern int readline_on;
 void
 gcl_init_readline_function(void);
 
@@ -603,6 +605,9 @@ gcl_init_string_function(void);
 void
 gcl_init_symbol_function(void);
 
+void
+gcl_init_socket_function(void);
+
 void
 gcl_init_hash(void);
 
