@@ -189,14 +189,16 @@ enum type what_to_collect;
 void
 enter_mark_origin(object *p)
 {
-  unsigned long np=page(p);
 /*   if (np>=MAXPAGE) */
 /*     error("Address supplied to enter_mar_origin out of range"); */
   if (mark_origin_max >= MARK_ORIGIN_MAX)
     error("too many mark origins");
 #ifdef SGC
-  if (np<MAXPAGE)
-    sgc_type_map[np] |= SGC_PERM_WRITABLE ;
+ {
+   unsigned long np=page(p);
+   if (np<MAXPAGE)
+     sgc_type_map[np] |= SGC_PERM_WRITABLE ;
+ }
 #endif	
   mark_origin[mark_origin_max++] = p;
 }
@@ -1112,7 +1114,7 @@ GBC(enum type t) {
 	   (sgc_enabled ? sgc_count_type(t) : tm_of(t)->tm_npage),
 	   (tm_table[(int)t].tm_name)+1);
 #else
-    printf("[%s for %d %s pages..",
+    printf("[%s for %ld %s pages..",
 	   ("GC"),
 	   (tm_of(t)->tm_npage),
 	   (tm_table[(int)t].tm_name)+1);
@@ -1435,7 +1437,7 @@ FFN(siLreset_gbc_count)(void) {
   check_arg(0);
   
   for (i = 0;  i < (int)t_other;  i++)
-    tm_table[i].tm_gbccount = tm_table[i].tm_adjgbccnt = 0;
+    tm_table[i].tm_gbccount = tm_table[i].tm_adjgbccnt = tm_table[i].tm_opt_maxpage = 0;
 }
 
 /* copy S bytes starting at P to beyond rb_pointer1 (temporarily)
