@@ -256,8 +256,6 @@ coerce_to_filename(object pathname, char *p)
     
 }
 
-
-
 object
 truename(object pathname)
 {
@@ -266,7 +264,6 @@ truename(object pathname)
 	char truefilename[MAXPATHLEN];
 	char current_directory[MAXPATHLEN];
 	char directory[MAXPATHLEN];
-	static char *getwd(char *buffer);
 #ifdef __MINGW32__ 
         DWORD current_directory_length =
             GetCurrentDirectory ( MAXPATHLEN, current_directory ); 
@@ -282,6 +279,40 @@ truename(object pathname)
     
 	coerce_to_filename(pathname, filename);
 	
+#ifdef S_IFLNK
+ {
+
+   struct stat filestatus;
+   int islinkcount=8;
+
+   if (lstat(filename, &filestatus) >= 0)
+
+	while (((filestatus.st_mode&S_IFMT) == S_IFLNK) && (--islinkcount>0)) {
+
+	  char newname[MAXPATHLEN];
+	  int newlen;
+
+	  newlen=readlink(filename,newname,MAXPATHLEN-1);
+	  if (newlen < 0)
+	    return((FEerror("Symlink broken at ~S.",1,pathname),Cnil));
+
+	  for (p = filename, q = 0;  *p != '\0';  p++)
+	    if (*p == '/') q = p;
+	  if (q == 0 || *newname == '/')
+	    q = filename;
+	  else
+	    q++;
+
+	  memcpy(q,newname,newlen);
+	  q[newlen]=0;
+	  if (lstat(filename, &filestatus) < 0) 
+	    islinkcount=0; /* It would be ANSI to do the following :
+			      return(file_error("Symlink broken at ~S.",pathname));
+			      but this would break DIRECTORY if a file points to nowhere */
+	}
+ }
+#endif
+
 	for (p = filename, q = 0;  *p != '\0';  p++)
 		if (*p == '/')
 			q = p;
@@ -374,7 +405,7 @@ file_exists(object file)
         }
 #endif        
 
-	if (stat(filename, &filestatus) >= 0)
+	if (stat(filename, &filestatus) >= 0 && !S_ISDIR(filestatus.st_mode))
 	  {
 #ifdef AIX
 	    /* if /tmp/foo is not a directory /tmp/foo/ should not exist */
@@ -388,7 +419,7 @@ file_exists(object file)
 	else
 	  if (sSAallow_gzipped_fileA->s.s_dbind != sLnil
 	      && (strcat(filename,".gz"),
-		  stat(filename, &filestatus) >= 0))
+		  stat(filename, &filestatus) >= 0 && !S_ISDIR(filestatus.st_mode)))
 	      
 	      return TRUE;
 
@@ -396,6 +427,18 @@ file_exists(object file)
 		return(FALSE);
 }
 
+FILE *
+fopen_not_dir(char *filename,char * option) {
+
+  struct stat ss;
+
+  if (!stat(filename,&ss) && S_ISDIR(ss.st_mode))
+    return NULL;
+  else
+    return fopen(filename,option);
+
+}
+
 FILE *
 backup_fopen(char *filename, char *option)
 {
@@ -515,7 +558,8 @@ LFD(Lfile_write_date)(void)
 	check_arg(1);
 	check_type_or_pathname_string_symbol_stream(&vs_base[0]);
 	coerce_to_filename(vs_base[0], filename);
-	if (stat(filename, &filestatus) < 0) { vs_base[0] = Cnil; return;}
+	if (stat(filename, &filestatus) < 0 || S_ISDIR(filestatus.st_mode))
+	  { vs_base[0] = Cnil; return;}
 	vs_base[0] = unix_time_to_universal_time(filestatus.st_mtime);
 }
 
@@ -532,7 +576,8 @@ LFD(Lfile_author)(void)
 	check_arg(1);
 	check_type_or_pathname_string_symbol_stream(&vs_base[0]);
 	coerce_to_filename(vs_base[0], filename);
-	if (stat(filename, &filestatus) < 0) { vs_base[0] = Cnil; return;}
+	if (stat(filename, &filestatus) < 0 || S_ISDIR(filestatus.st_mode))
+	  { vs_base[0] = Cnil; return;}
 	pwent = getpwuid(filestatus.st_uid);
 	vs_base[0] = make_simple_string(pwent->pw_name);
 #else
